@@ -2,18 +2,15 @@ use chrono::offset::{Local, TimeZone};
 use chrono::{Date, Duration};
 use plotters::prelude::*;
 fn parse_time(t: &str) -> Date<Local> {
-    return Local
+    Local
         .datetime_from_str(&format!("{} 0:0", t), "%Y-%m-%d %H:%M")
         .unwrap()
-        .date();
+        .date()
 }
 fn main() -> Result<(), Box<dyn std::error::Error>> {
     let data = get_data();
-    let mut backend = BitMapBackend::new("examples/outputs/stock.png", (1024, 768));
-    backend.open()?;
-    let root: DrawingArea<_, _> = backend.into();
-    let font = Into::<FontDesc>::into("Arial").resize(50.0);
-    root.fill(&RGBColor(255, 255, 255))?;
+    let root = BitMapBackend::new("examples/outputs/stock.png", (1024, 768)).into_drawing_area();
+    root.fill(&White)?;
 
     let (to_date, from_date) = (
         parse_time(&data[0].0) + Duration::days(1),
@@ -23,29 +20,17 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     let mut chart = ChartBuilder::on(&root)
         .x_label_area_size(40)
         .y_label_area_size(40)
-        .caption("MSFT Stock Price", &font)
-        .build_ranged(from_date..to_date, 110f32..135f32);
+        .caption("MSFT Stock Price", &("Arial", 50.0).into_font())
+        .build_ranged(from_date..to_date, 110f32..135f32)?;
 
-    chart
-        .configure_mesh()
-        .line_style_2(&RGBColor(255, 255, 255))
-        .draw()?;
+    chart.configure_mesh().line_style_2(&White).draw()?;
 
-    chart.draw_series(data.iter().map(|x| {
-        CandleStick::<_, _>::new::<&RGBColor, &RGBColor>(
-            parse_time(x.0),
-            x.1,
-            x.2,
-            x.3,
-            x.4,
-            &RGBColor(0, 255, 0),
-            &RGBColor(255, 0, 0),
-            15,
-        )
-    }))?;
+    chart.draw_series(
+        data.iter()
+            .map(|x| CandleStick::new(parse_time(x.0), x.1, x.2, x.3, x.4, &Green, &Red, 15)),
+    )?;
 
-    root.close()?;
-    return Ok(());
+    Ok(())
 }
 
 fn get_data() -> Vec<(&'static str, f32, f32, f32, f32)> {
