@@ -29,7 +29,7 @@ impl Rect {
     ) -> impl Iterator<Item = Rect> + 'a {
         let (mut x0, mut y0) = (self.x0, self.y0);
         let (full_x, full_y) = (self.x1, self.y1);
-        return break_points
+        break_points
             .into_iter()
             .chain(once(if vertical { &self.y1 } else { &self.x1 }))
             .map(move |&p| {
@@ -43,33 +43,30 @@ impl Rect {
                     x0 = x1;
                 }
 
-                return ret;
-            });
+                ret
+            })
     }
 
     /// Evently split the regtangle to a row * col mesh
     fn split_evenly<'a>(&'a self, (row, col): (usize, usize)) -> impl Iterator<Item = Rect> + 'a {
         fn compute_evenly_split(from: i32, to: i32, n: usize, idx: usize) -> i32 {
             let size = (to - from) as usize;
-            return from + idx as i32 * (size / n) as i32 + if size % n < idx { 1 } else { 0 };
+            from + idx as i32 * (size / n) as i32 + if size % n < idx { 1 } else { 0 }
         }
-        return (0..row)
-            .into_iter()
+        (0..row)
             .map(move |x| repeat(x).zip(0..col))
             .flatten()
-            .map(move |(ri, ci)| {
-                return Self {
-                    y0: compute_evenly_split(self.y0, self.y1, row, ri),
-                    y1: compute_evenly_split(self.y0, self.y1, row, ri + 1),
-                    x0: compute_evenly_split(self.x0, self.x1, col, ci),
-                    x1: compute_evenly_split(self.x0, self.x1, col, ci + 1),
-                };
-            });
+            .map(move |(ri, ci)| Self {
+                y0: compute_evenly_split(self.y0, self.y1, row, ri),
+                y1: compute_evenly_split(self.y0, self.y1, row, ri + 1),
+                x0: compute_evenly_split(self.x0, self.x1, col, ci),
+                x1: compute_evenly_split(self.x0, self.x1, col, ci + 1),
+            })
     }
 
     /// Make the coordinate in the range of the rectangle
     fn truncate(&self, p: (i32, i32)) -> (i32, i32) {
-        return (p.0.min(self.x1).max(self.x0), p.1.min(self.y1).max(self.y0));
+        (p.0.min(self.x1).max(self.x0), p.1.min(self.y1).max(self.y0))
     }
 }
 
@@ -82,11 +79,11 @@ pub struct DrawingArea<DB: DrawingBackend, CT: CoordTranslate> {
 
 impl<DB: DrawingBackend, CT: CoordTranslate + Clone> Clone for DrawingArea<DB, CT> {
     fn clone(&self) -> Self {
-        return Self {
+        Self {
             backend: self.copy_backend_ref(),
             rect: self.rect.clone(),
             coord: self.coord.clone(),
-        };
+        }
     }
 }
 
@@ -105,13 +102,13 @@ pub enum DrawingAreaErrorKind<E: Error> {
 
 impl<E: Error> std::fmt::Display for DrawingAreaErrorKind<E> {
     fn fmt(&self, fmt: &mut std::fmt::Formatter) -> Result<(), std::fmt::Error> {
-        return match self {
+        match self {
             DrawingAreaErrorKind::BackendError(e) => write!(fmt, "backend error: {}", e),
             DrawingAreaErrorKind::SharingError => {
                 write!(fmt, "Mulitple backend operation in progress")
             }
             DrawingAreaErrorKind::LayoutError => write!(fmt, "Bad layout"),
-        };
+        }
     }
 }
 
@@ -123,7 +120,7 @@ type DrawingAreaError<T: DrawingBackend> = DrawingAreaErrorKind<T::ErrorType>;
 impl<DB: DrawingBackend> From<DB> for DrawingArea<DB, Shift> {
     fn from(backend: DB) -> Self {
         let (x1, y1) = backend.get_size();
-        return Self {
+        Self {
             rect: Rect {
                 x0: 0,
                 y0: 0,
@@ -132,7 +129,19 @@ impl<DB: DrawingBackend> From<DB> for DrawingArea<DB, Shift> {
             },
             backend: Rc::new(RefCell::new(backend)),
             coord: Shift((0, 0)),
-        };
+        }
+    }
+}
+
+/// A type which can be converted into a root drawing area
+pub trait IntoDrawingArea: DrawingBackend + Sized {
+    /// Convert the type into a root drawing area
+    fn into_drawing_area(self) -> DrawingArea<Self, Shift>;
+}
+
+impl<T: DrawingBackend> IntoDrawingArea for T {
+    fn into_drawing_area(self) -> DrawingArea<T, Shift> {
+        self.into()
     }
 }
 
@@ -147,55 +156,54 @@ impl<DB: DrawingBackend, X: Ranged, Y: Ranged> DrawingArea<DB, RangedCoord<X, Y>
     where
         DrawFunc: FnMut(&mut DB, MeshLine<X, Y>) -> Result<(), DrawingErrorKind<DB::ErrorType>>,
     {
-        return self.backend_ops(move |b| {
-            return self.coord.draw_mesh(y_count_max, x_count_max, |line| {
-                return draw_func(b, line);
-            });
-        });
+        self.backend_ops(move |b| {
+            self.coord
+                .draw_mesh(y_count_max, x_count_max, |line| draw_func(b, line))
+        })
     }
 
     /// Get the range of X of the guest coordinate for current drawing area
     pub fn get_x_range(&self) -> Range<X::ValueType> {
-        return self.coord.get_x_range();
+        self.coord.get_x_range()
     }
 
     /// Get the range of Y of the guest coordinate for current drawing area
     pub fn get_y_range(&self) -> Range<Y::ValueType> {
-        return self.coord.get_y_range();
+        self.coord.get_y_range()
     }
 }
 
 impl<DB: DrawingBackend, CT: CoordTranslate> DrawingArea<DB, CT> {
     /// Get the left upper conner of this area in the drawing backend
     pub fn get_base_pixel(&self) -> BackendCoord {
-        return (self.rect.x0, self.rect.y0);
+        (self.rect.x0, self.rect.y0)
     }
 
     /// Strip the applied coordinate specification and returns a shift-based drawing area
     pub fn strip_coord_spec(&self) -> DrawingArea<DB, Shift> {
-        return DrawingArea {
+        DrawingArea {
             rect: self.rect.clone(),
             backend: self.copy_backend_ref(),
             coord: Shift((self.rect.x0, self.rect.y0)),
-        };
+        }
     }
 
     /// Get the area dimension in pixel
     pub fn dim_in_pixel(&self) -> (u32, u32) {
-        return (
+        (
             (self.rect.x1 - self.rect.x0) as u32,
             (self.rect.y1 - self.rect.y0) as u32,
-        );
+        )
     }
 
     /// Get the pixel range of this area
     pub fn get_pixel_range(&self) -> (Range<i32>, Range<i32>) {
-        return (self.rect.x0..self.rect.x1, self.rect.y0..self.rect.y1);
+        (self.rect.x0..self.rect.x1, self.rect.y0..self.rect.y1)
     }
 
     /// Copy the drawing contenxt
     fn copy_backend_ref(&self) -> Rc<RefCell<DB>> {
-        return self.backend.clone();
+        self.backend.clone()
     }
 
     /// Perform operation on the drawing backend
@@ -204,22 +212,24 @@ impl<DB: DrawingBackend, CT: CoordTranslate> DrawingArea<DB, CT> {
         ops: O,
     ) -> Result<R, DrawingAreaError<DB>> {
         if let Ok(mut db) = self.backend.try_borrow_mut() {
-            return ops(&mut db).map_err(|what| DrawingAreaErrorKind::BackendError(what));
+            db.ensure_prepared()
+                .map_err(DrawingAreaErrorKind::BackendError)?;
+            ops(&mut db).map_err(DrawingAreaErrorKind::BackendError)
         } else {
-            return Err(DrawingAreaErrorKind::SharingError);
+            Err(DrawingAreaErrorKind::SharingError)
         }
     }
 
     /// Fill the entire drawing area with a color
     pub fn fill<ColorType: Color>(&self, color: &ColorType) -> Result<(), DrawingAreaError<DB>> {
-        return self.backend_ops(|backend| {
+        self.backend_ops(|backend| {
             backend.draw_rect(
                 (self.rect.x0, self.rect.y0),
                 (self.rect.x1, self.rect.y1),
                 color,
                 true,
             )
-        });
+        })
     }
 
     /// Draw a single pixel
@@ -229,39 +239,30 @@ impl<DB: DrawingBackend, CT: CoordTranslate> DrawingArea<DB, CT> {
         color: &ColorType,
     ) -> Result<(), DrawingAreaError<DB>> {
         let pos = self.coord.translate(&pos);
-        return self.backend_ops(|b| {
-            return b.draw_pixel(pos, color);
-        });
+        self.backend_ops(|b| b.draw_pixel(pos, color))
     }
 
-    /// Open the backend
-    pub fn open(&self) -> Result<(), DrawingAreaError<DB>> {
-        return self.backend_ops(|b| b.open());
-    }
-
-    /// Close the backend
-    pub fn close(&self) -> Result<(), DrawingAreaError<DB>> {
-        return self.backend_ops(|b| {
-            return b.close();
-        });
+    /// Present all the pending changes to the backend
+    pub fn present(&self) -> Result<(), DrawingAreaError<DB>> {
+        self.backend_ops(|b| b.present())
     }
 
     /// Draw an high-level element
     pub fn draw<'a, E>(&self, element: &'a E) -> Result<(), DrawingAreaError<DB>>
     where
         &'a E: PointCollection<'a, CT::From>,
-        E: Drawable,
+        E: Drawable<DB>,
     {
         let backend_coords = element.point_iter().into_iter().map(|p| {
             let b = p.borrow();
-            return self.rect.truncate(self.coord.translate(b));
+            self.rect.truncate(self.coord.translate(b))
         });
-        return self.backend_ops(move |b| element.draw(backend_coords, b));
+        self.backend_ops(move |b| element.draw(backend_coords, b))
     }
 
     /// Map coordinate to the backend coordinate
     pub fn map_coordinate(&self, coord: &CT::From) -> BackendCoord {
-        return self.coord.translate(coord);
+        self.coord.translate(coord)
     }
 }
 
@@ -280,21 +281,21 @@ impl<DB: DrawingBackend> DrawingArea<DB, Shift> {
 
         self.coord = Shift((self.rect.x0, self.rect.y0));
 
-        return self;
+        self
     }
 
     /// Apply a new coord transformation object and returns a new drawing area
     pub fn apply_coord_spec<CT: CoordTranslate>(&self, coord_spec: CT) -> DrawingArea<DB, CT> {
-        return DrawingArea {
+        DrawingArea {
             rect: self.rect.clone(),
             backend: self.copy_backend_ref(),
             coord: coord_spec,
-        };
+        }
     }
 
     /// Create a margin for the given drawing area and returns the new drawing area
     pub fn margin(&self, top: i32, bottom: i32, left: i32, right: i32) -> DrawingArea<DB, Shift> {
-        return DrawingArea {
+        DrawingArea {
             rect: Rect {
                 x0: self.rect.x0 + left,
                 y0: self.rect.y0 + top,
@@ -303,50 +304,43 @@ impl<DB: DrawingBackend> DrawingArea<DB, Shift> {
             },
             backend: self.copy_backend_ref(),
             coord: Shift((self.rect.x0 + left, self.rect.y0 + top)),
-        };
+        }
     }
 
     /// Split the drawing area vertically
     pub fn split_vertically(&self, y: i32) -> (Self, Self) {
         let split_point = [y + self.rect.y0];
-        let mut ret = self.rect.split(split_point.iter(), true).map(|rect| {
-            return Self {
-                rect: rect.clone(),
-                backend: self.copy_backend_ref(),
-                coord: Shift((rect.x0, rect.y0)),
-            };
+        let mut ret = self.rect.split(split_point.iter(), true).map(|rect| Self {
+            rect: rect.clone(),
+            backend: self.copy_backend_ref(),
+            coord: Shift((rect.x0, rect.y0)),
         });
 
-        return (ret.next().unwrap(), ret.next().unwrap());
+        (ret.next().unwrap(), ret.next().unwrap())
     }
 
     /// Split the drawing area horizentally
     pub fn split_horizentally(&self, x: i32) -> (Self, Self) {
         let split_point = [x + self.rect.x0];
-        let mut ret = self.rect.split(split_point.iter(), false).map(|rect| {
-            return Self {
-                rect: rect.clone(),
-                backend: self.copy_backend_ref(),
-                coord: Shift((rect.x0, rect.y0)),
-            };
+        let mut ret = self.rect.split(split_point.iter(), false).map(|rect| Self {
+            rect: rect.clone(),
+            backend: self.copy_backend_ref(),
+            coord: Shift((rect.x0, rect.y0)),
         });
 
-        return (ret.next().unwrap(), ret.next().unwrap());
+        (ret.next().unwrap(), ret.next().unwrap())
     }
 
     /// Split the drawing area evenly
     pub fn split_evenly(&self, (row, col): (usize, usize)) -> Vec<Self> {
-        return self
-            .rect
+        self.rect
             .split_evenly((row, col))
-            .map(|rect| {
-                return Self {
-                    rect: rect.clone(),
-                    backend: self.copy_backend_ref(),
-                    coord: Shift((rect.x0, rect.y0)),
-                };
+            .map(|rect| Self {
+                rect: rect.clone(),
+                backend: self.copy_backend_ref(),
+                coord: Shift((rect.x0, rect.y0)),
             })
-            .collect();
+            .collect()
     }
 
     /// Draw a title of the drawing area and return the remaining drawing area
@@ -380,7 +374,7 @@ impl<DB: DrawingBackend> DrawingArea<DB, Shift> {
             )
         })?;
 
-        return Ok(Self {
+        Ok(Self {
             rect: Rect {
                 x0: self.rect.x0,
                 y0: self.rect.y0 + 10 + text_h as i32,
@@ -389,7 +383,7 @@ impl<DB: DrawingBackend> DrawingArea<DB, Shift> {
             },
             backend: self.copy_backend_ref(),
             coord: Shift((self.rect.x0, self.rect.y0 + 10 + text_h as i32)),
-        });
+        })
     }
 
     /// Draw text on the drawing area
@@ -399,19 +393,19 @@ impl<DB: DrawingBackend> DrawingArea<DB, Shift> {
         style: &TextStyle,
         pos: BackendCoord,
     ) -> Result<(), DrawingAreaError<DB>> {
-        return self.backend_ops(|b| {
+        self.backend_ops(|b| {
             b.draw_text(
                 text,
                 style.font,
                 (pos.0 + self.rect.x0, pos.1 + self.rect.y0),
                 &Box::new(style.color),
             )
-        });
+        })
     }
 }
 
 impl<DB: DrawingBackend, CT: CoordTranslate> DrawingArea<DB, CT> {
     pub fn into_coord_spec(self) -> CT {
-        return self.coord;
+        self.coord
     }
 }
