@@ -2,21 +2,26 @@ use crate::drawing::backend::{BackendCoord, DrawingBackend, DrawingErrorKind};
 use crate::style::Color;
 use image::{ImageError, Rgb, RgbImage};
 
+use std::path::Path;
+
 /// The backend that drawing a bitmap
 pub struct BitMapBackend<'a> {
     /// The path to the image
-    path: &'a str,
+    path: &'a Path,
     /// The image object
     img: RgbImage,
+    /// Flag indicates if the bitmap has been saved
+    saved: bool,
 }
 
 impl<'a> BitMapBackend<'a> {
     /// Create a new bitmap backend
-    pub fn new(path: &'a str, dimension: (u32, u32)) -> Self {
-        return Self {
-            path,
+    pub fn new<T: AsRef<Path> + ?Sized>(path: &'a T, dimension: (u32, u32)) -> Self {
+        Self {
+            path: path.as_ref(),
             img: RgbImage::new(dimension.0, dimension.1),
-        };
+            saved: false,
+        }
     }
 }
 
@@ -24,17 +29,19 @@ impl<'a> DrawingBackend for BitMapBackend<'a> {
     type ErrorType = ImageError;
 
     fn get_size(&self) -> (u32, u32) {
-        return (self.img.width(), self.img.height());
+        (self.img.width(), self.img.height())
     }
 
-    fn open(&mut self) -> Result<(), DrawingErrorKind<ImageError>> {
+    fn ensure_prepared(&mut self) -> Result<(), DrawingErrorKind<ImageError>> {
         Ok(())
     }
 
-    fn close(&mut self) -> Result<(), DrawingErrorKind<ImageError>> {
+    fn present(&mut self) -> Result<(), DrawingErrorKind<ImageError>> {
         self.img
             .save(&self.path)
-            .map_err(|x| DrawingErrorKind::DrawingError(ImageError::IoError(x)))
+            .map_err(|x| DrawingErrorKind::DrawingError(ImageError::IoError(x)))?;
+        self.saved = true;
+        Ok(())
     }
 
     fn draw_pixel<C: Color>(
@@ -71,9 +78,18 @@ impl<'a> DrawingBackend for BitMapBackend<'a> {
                 .iter_mut()
                 .zip(&new_color)
                 .for_each(|(old, new)| {
-                    *old = (*old as f64 * (1.0 - alpha) + *new as f64 * alpha).min(255.0) as u8;
+                    *old = (f64::from(*old) * (1.0 - alpha) + f64::from(*new) * alpha).min(255.0)
+                        as u8;
                 });
         }
-        return Ok(());
+        Ok(())
+    }
+}
+
+impl Drop for BitMapBackend<'_> {
+    fn drop(&mut self) {
+        if !self.saved {
+            self.present().expect("Unable to save the bitmap");
+        }
     }
 }
