@@ -2,10 +2,11 @@ use js_sys::JSON;
 use wasm_bindgen::{JsCast, JsValue};
 use web_sys::{window, CanvasRenderingContext2d, HtmlCanvasElement};
 
-use crate::drawing::backend::{BackendCoord, DrawingBackend, DrawingErrorKind};
+use crate::drawing::backend::{BackendCoord, BackendStyle, DrawingBackend, DrawingErrorKind};
 use crate::style::{Color, FontDesc};
 
 /// The backend that is drawing on the HTML canvas
+/// TODO: Support double bufferring
 pub struct CanvasBackend {
     canvas: HtmlCanvasElement,
     context: CanvasRenderingContext2d,
@@ -20,7 +21,7 @@ impl std::fmt::Display for CanvasError {
             "Canvas Error: {}",
             JSON::stringify(&self.0)
                 .map(|s| Into::<String>::into(&s))
-                .unwrap_or("Unknown".to_string())
+                .unwrap_or_else(|_| "Unknown".to_string())
         );
     }
 }
@@ -32,7 +33,7 @@ impl std::fmt::Debug for CanvasError {
             "CanvasError({})",
             JSON::stringify(&self.0)
                 .map(|s| Into::<String>::into(&s))
-                .unwrap_or("Unknown".to_string())
+                .unwrap_or_else(|_| "Unknown".to_string())
         );
     }
 }
@@ -48,119 +49,143 @@ impl CanvasBackend {
         let canvas = document.get_element_by_id(elem_id)?;
         let canvas: HtmlCanvasElement = canvas.dyn_into().ok()?;
         let context: CanvasRenderingContext2d = canvas.get_context("2d").ok()??.dyn_into().ok()?;
-        return Some(CanvasBackend { canvas, context });
+        Some(CanvasBackend { canvas, context })
     }
 }
 
 fn make_canvas_color<C: Color>(color: &C) -> JsValue {
     let (r, g, b) = color.rgb();
     let a = color.alpha();
-    return format!("rgba({},{},{},{})", r, g, b, a).into();
+    format!("rgba({},{},{},{})", r, g, b, a).into()
 }
 
 impl DrawingBackend for CanvasBackend {
     type ErrorType = CanvasError;
 
     fn get_size(&self) -> (u32, u32) {
-        return (self.canvas.width(), self.canvas.height());
+        (self.canvas.width(), self.canvas.height())
     }
 
-    fn open(&mut self) -> Result<(), DrawingErrorKind<CanvasError>> {
-        return Ok(());
+    fn ensure_prepared(&mut self) -> Result<(), DrawingErrorKind<CanvasError>> {
+        Ok(())
     }
 
-    fn close(&mut self) -> Result<(), DrawingErrorKind<CanvasError>> {
-        return Ok(());
+    fn present(&mut self) -> Result<(), DrawingErrorKind<CanvasError>> {
+        Ok(())
     }
 
     fn draw_pixel<C: Color>(
         &mut self,
         point: BackendCoord,
-        color: &C,
+        style: &C,
     ) -> Result<(), DrawingErrorKind<CanvasError>> {
-        self.context.set_fill_style(&make_canvas_color(color));
+        if style.alpha() == 0.0 {
+            return Ok(());
+        }
+
         self.context
-            .fill_rect(point.0 as f64, point.1 as f64, 1.0, 1.0);
-        return Ok(());
+            .set_fill_style(&make_canvas_color(style.as_color()));
+        self.context
+            .fill_rect(f64::from(point.0), f64::from(point.1), 1.0, 1.0);
+        Ok(())
     }
 
-    fn draw_line<C: Color>(
+    fn draw_line<S: BackendStyle>(
         &mut self,
         from: BackendCoord,
         to: BackendCoord,
-        color: &C,
+        style: &S,
     ) -> Result<(), DrawingErrorKind<Self::ErrorType>> {
-        self.context.set_stroke_style(&make_canvas_color(color));
+        if style.as_color().alpha() == 0.0 {
+            return Ok(());
+        }
+
+        self.context
+            .set_stroke_style(&make_canvas_color(style.as_color()));
         self.context.begin_path();
-        self.context.move_to(from.0 as f64, from.1 as f64);
-        self.context.line_to(to.0 as f64, to.1 as f64);
+        self.context.move_to(f64::from(from.0), f64::from(from.1));
+        self.context.line_to(f64::from(to.0), f64::from(to.1));
         self.context.stroke();
-        return Ok(());
+        Ok(())
     }
 
-    fn draw_rect<C: Color>(
+    fn draw_rect<S: BackendStyle>(
         &mut self,
         upper_left: BackendCoord,
         bottom_right: BackendCoord,
-        color: &C,
+        style: &S,
         fill: bool,
     ) -> Result<(), DrawingErrorKind<Self::ErrorType>> {
+        if style.as_color().alpha() == 0.0 {
+            return Ok(());
+        }
         if fill {
-            self.context.set_fill_style(&make_canvas_color(color));
+            self.context
+                .set_fill_style(&make_canvas_color(style.as_color()));
             self.context.fill_rect(
-                upper_left.0 as f64,
-                upper_left.1 as f64,
-                (bottom_right.0 - upper_left.0) as f64,
-                (bottom_right.1 - upper_left.1) as f64,
+                f64::from(upper_left.0),
+                f64::from(upper_left.1),
+                f64::from(bottom_right.0 - upper_left.0),
+                f64::from(bottom_right.1 - upper_left.1),
             );
         } else {
-            self.context.set_stroke_style(&make_canvas_color(color));
+            self.context
+                .set_stroke_style(&make_canvas_color(style.as_color()));
             self.context.stroke_rect(
-                upper_left.0 as f64,
-                upper_left.1 as f64,
-                (bottom_right.0 - upper_left.0) as f64,
-                (bottom_right.1 - upper_left.1) as f64,
+                f64::from(upper_left.0),
+                f64::from(upper_left.1),
+                f64::from(bottom_right.0 - upper_left.0),
+                f64::from(bottom_right.1 - upper_left.1),
             );
         }
-        return Ok(());
+        Ok(())
     }
 
-    fn draw_path<C: Color, I: IntoIterator<Item = BackendCoord>>(
+    fn draw_path<S: BackendStyle, I: IntoIterator<Item = BackendCoord>>(
         &mut self,
         path: I,
-        color: &C,
+        style: &S,
     ) -> Result<(), DrawingErrorKind<Self::ErrorType>> {
+        if style.as_color().alpha() == 0.0 {
+            return Ok(());
+        }
         let mut path = path.into_iter();
         self.context.begin_path();
         if let Some(start) = path.next() {
-            self.context.set_stroke_style(&make_canvas_color(color));
-            self.context.move_to(start.0 as f64, start.1 as f64);
+            self.context
+                .set_stroke_style(&make_canvas_color(style.as_color()));
+            self.context.move_to(f64::from(start.0), f64::from(start.1));
             for next in path {
-                self.context.line_to(next.0 as f64, next.1 as f64);
+                self.context.line_to(f64::from(next.0), f64::from(next.1));
             }
         }
         self.context.stroke();
-        return Ok(());
+        Ok(())
     }
 
-    fn draw_circle<C: Color>(
+    fn draw_circle<S: BackendStyle>(
         &mut self,
         center: BackendCoord,
         radius: u32,
-        color: &C,
+        style: &S,
         fill: bool,
     ) -> Result<(), DrawingErrorKind<Self::ErrorType>> {
+        if style.as_color().alpha() == 0.0 {
+            return Ok(());
+        }
         if fill {
-            self.context.set_fill_style(&make_canvas_color(color));
+            self.context
+                .set_fill_style(&make_canvas_color(style.as_color()));
         } else {
-            self.context.set_stroke_style(&make_canvas_color(color));
+            self.context
+                .set_stroke_style(&make_canvas_color(style.as_color()));
         }
         self.context.begin_path();
         self.context
             .arc(
-                center.0 as f64,
-                center.1 as f64,
-                radius as f64,
+                f64::from(center.0),
+                f64::from(center.1),
+                f64::from(radius),
                 0.0,
                 std::f64::consts::PI * 2.0,
             )
@@ -170,7 +195,7 @@ impl DrawingBackend for CanvasBackend {
         } else {
             self.context.stroke();
         }
-        return Ok(());
+        Ok(())
     }
 
     fn draw_text<'b, C: Color>(
@@ -180,13 +205,16 @@ impl DrawingBackend for CanvasBackend {
         pos: BackendCoord,
         color: &C,
     ) -> Result<(), DrawingErrorKind<Self::ErrorType>> {
+        if color.alpha() == 0.0 {
+            return Ok(());
+        }
         self.context.set_text_baseline("bottom");
         self.context.set_fill_style(&make_canvas_color(color));
         self.context
             .set_font(&format!("{}px {}", font.get_size(), font.get_name()));
         self.context
-            .fill_text(text, pos.0 as f64, pos.1 as f64 + font.get_size())
+            .fill_text(text, f64::from(pos.0), f64::from(pos.1) + font.get_size())
             .map_err(|e| DrawingErrorKind::DrawingError(CanvasError(e)))?;
-        return Ok(());
+        Ok(())
     }
 }
