@@ -5,10 +5,11 @@ The SVG image drawing backend
 use svg::node::element::{Circle, Line, Polyline, Rectangle, Text};
 use svg::Document;
 
-use crate::drawing::backend::{BackendCoord, DrawingBackend, DrawingErrorKind};
+use crate::drawing::backend::{BackendCoord, BackendStyle, DrawingBackend, DrawingErrorKind};
 use crate::style::{Color, FontDesc};
 
 use std::io::Error;
+use std::path::Path;
 
 fn make_svg_color<C: Color>(color: &C) -> String {
     let (r, g, b) = color.rgb();
@@ -21,9 +22,10 @@ fn make_svg_opacity<C: Color>(color: &C) -> String {
 
 /// The SVG image drawing backend
 pub struct SVGBackend<'a> {
-    path: &'a str,
+    path: &'a Path,
     size: (u32, u32),
     document: Option<Document>,
+    saved: bool,
 }
 
 impl<'a> SVGBackend<'a> {
@@ -32,13 +34,15 @@ impl<'a> SVGBackend<'a> {
         std::mem::swap(&mut temp, &mut self.document);
         self.document = Some(op(temp.unwrap()));
     }
+
     /// Create a new SVG drawing backend
-    pub fn new(path: &'a str, size: (u32, u32)) -> Self {
-        return Self {
-            path,
+    pub fn new<T: AsRef<Path> + ?Sized>(path: &'a T, size: (u32, u32)) -> Self {
+        Self {
+            path: path.as_ref(),
             size,
             document: Some(Document::new().set("viewBox", (0, 0, size.0, size.1))),
-        };
+            saved: false,
+        }
     }
 }
 
@@ -46,16 +50,18 @@ impl<'a> DrawingBackend for SVGBackend<'a> {
     type ErrorType = Error;
 
     fn get_size(&self) -> (u32, u32) {
-        return self.size;
+        self.size
     }
 
-    fn open(&mut self) -> Result<(), DrawingErrorKind<Error>> {
+    fn ensure_prepared(&mut self) -> Result<(), DrawingErrorKind<Error>> {
         Ok(())
     }
 
-    fn close(&mut self) -> Result<(), DrawingErrorKind<Error>> {
-        return svg::save(self.path, self.document.as_ref().unwrap())
-            .map_err(|x| DrawingErrorKind::DrawingError(x));
+    fn present(&mut self) -> Result<(), DrawingErrorKind<Error>> {
+        svg::save(self.path, self.document.as_ref().unwrap())
+            .map_err(DrawingErrorKind::DrawingError)?;
+        self.saved = true;
+        Ok(())
     }
 
     fn draw_pixel<C: Color>(
@@ -63,6 +69,9 @@ impl<'a> DrawingBackend for SVGBackend<'a> {
         point: BackendCoord,
         color: &C,
     ) -> Result<(), DrawingErrorKind<Error>> {
+        if color.alpha() == 0.0 {
+            return Ok(());
+        }
         let node = Rectangle::new()
             .set("x", point.0)
             .set("y", point.1)
@@ -72,33 +81,39 @@ impl<'a> DrawingBackend for SVGBackend<'a> {
             .set("opacity", make_svg_opacity(color))
             .set("fill", make_svg_color(color));
         self.update_document(|d| d.add(node));
-        return Ok(());
+        Ok(())
     }
 
-    fn draw_line<C: Color>(
+    fn draw_line<S: BackendStyle>(
         &mut self,
         from: BackendCoord,
         to: BackendCoord,
-        color: &C,
+        style: &S,
     ) -> Result<(), DrawingErrorKind<Self::ErrorType>> {
+        if style.as_color().alpha() == 0.0 {
+            return Ok(());
+        }
         let node = Line::new()
             .set("x1", from.0)
             .set("y1", from.1)
             .set("x2", to.0)
             .set("y2", to.1)
-            .set("opacity", make_svg_opacity(color))
-            .set("stroke", make_svg_color(color));
+            .set("opacity", make_svg_opacity(style.as_color()))
+            .set("stroke", make_svg_color(style.as_color()));
         self.update_document(|d| d.add(node));
-        return Ok(());
+        Ok(())
     }
 
-    fn draw_rect<C: Color>(
+    fn draw_rect<S: BackendStyle>(
         &mut self,
         upper_left: BackendCoord,
         bottom_right: BackendCoord,
-        color: &C,
+        style: &S,
         fill: bool,
     ) -> Result<(), DrawingErrorKind<Self::ErrorType>> {
+        if style.as_color().alpha() == 0.0 {
+            return Ok(());
+        }
         let mut node = Rectangle::new()
             .set("x", upper_left.0)
             .set("y", upper_left.1)
@@ -107,47 +122,53 @@ impl<'a> DrawingBackend for SVGBackend<'a> {
 
         if !fill {
             node = node
-                .set("opacity", make_svg_opacity(color))
-                .set("stroke", make_svg_color(color))
+                .set("opacity", make_svg_opacity(style.as_color()))
+                .set("stroke", make_svg_color(style.as_color()))
                 .set("fill", "none");
         } else {
             node = node
-                .set("opacity", make_svg_opacity(color))
-                .set("fill", make_svg_color(color))
+                .set("opacity", make_svg_opacity(style.as_color()))
+                .set("fill", make_svg_color(style.as_color()))
                 .set("stroke", "none");
         }
 
         self.update_document(|d| d.add(node));
-        return Ok(());
+        Ok(())
     }
 
-    fn draw_path<C: Color, I: IntoIterator<Item = BackendCoord>>(
+    fn draw_path<S: BackendStyle, I: IntoIterator<Item = BackendCoord>>(
         &mut self,
         path: I,
-        color: &C,
+        style: &S,
     ) -> Result<(), DrawingErrorKind<Self::ErrorType>> {
+        if style.as_color().alpha() == 0.0 {
+            return Ok(());
+        }
         let node = Polyline::new()
             .set("fill", "none")
-            .set("opacity", make_svg_opacity(color))
-            .set("stroke", make_svg_color(color))
+            .set("opacity", make_svg_opacity(style.as_color()))
+            .set("stroke", make_svg_color(style.as_color()))
             .set(
                 "points",
                 path.into_iter().fold(String::new(), |mut s, (x, y)| {
                     s.push_str(&format!("{},{} ", x, y));
-                    return s;
+                    s
                 }),
             );
         self.update_document(|d| d.add(node));
-        return Ok(());
+        Ok(())
     }
 
-    fn draw_circle<C: Color>(
+    fn draw_circle<S: BackendStyle>(
         &mut self,
         center: BackendCoord,
         radius: u32,
-        color: &C,
+        style: &S,
         fill: bool,
     ) -> Result<(), DrawingErrorKind<Self::ErrorType>> {
+        if style.as_color().alpha() == 0.0 {
+            return Ok(());
+        }
         let mut node = Circle::new()
             .set("cx", center.0)
             .set("cy", center.1)
@@ -155,18 +176,18 @@ impl<'a> DrawingBackend for SVGBackend<'a> {
 
         if !fill {
             node = node
-                .set("opacity", make_svg_opacity(color))
-                .set("stroke", make_svg_color(color))
+                .set("opacity", make_svg_opacity(style.as_color()))
+                .set("stroke", make_svg_color(style.as_color()))
                 .set("fill", "none");
         } else {
             node = node
-                .set("opacity", make_svg_opacity(color))
-                .set("fill", make_svg_color(color))
+                .set("opacity", make_svg_opacity(style.as_color()))
+                .set("fill", make_svg_color(style.as_color()))
                 .set("stroke", "none");
         }
 
         self.update_document(|d| d.add(node));
-        return Ok(());
+        Ok(())
     }
     fn draw_text<'b, C: Color>(
         &mut self,
@@ -175,10 +196,11 @@ impl<'a> DrawingBackend for SVGBackend<'a> {
         pos: BackendCoord,
         color: &C,
     ) -> Result<(), DrawingErrorKind<Self::ErrorType>> {
+        if color.alpha() == 0.0 {
+            return Ok(());
+        }
         let context = svg::node::Text::new(text);
-        let ((_, b), (_, _)) = font
-            .layout_box(text)
-            .map_err(|x| DrawingErrorKind::FontError(x))?;
+        let ((_, b), (_, _)) = font.layout_box(text).map_err(DrawingErrorKind::FontError)?;
         let node = Text::new()
             .set("x", pos.0)
             .set("y", pos.1 - b)
@@ -188,6 +210,14 @@ impl<'a> DrawingBackend for SVGBackend<'a> {
             .set("fill", make_svg_color(color))
             .add(context);
         self.update_document(|d| d.add(node));
-        return Ok(());
+        Ok(())
+    }
+}
+
+impl Drop for SVGBackend<'_> {
+    fn drop(&mut self) {
+        if !self.saved {
+            self.present().expect("Unable to save the SVG image");
+        }
     }
 }
