@@ -1,60 +1,71 @@
 use super::*;
+use crate::drawing::backend::DrawingBackend;
 use std::borrow::Borrow;
 use std::iter::{once, Once};
+use std::marker::PhantomData;
 use std::ops::Add;
 
 /// An empty composibable element, which is the start point of an ad-hoc composible element
-pub struct EmptyElement<Coord> {
+pub struct EmptyElement<Coord, DB: DrawingBackend> {
     coord: Coord,
+    phantom: PhantomData<DB>,
 }
 
-impl<Coord> EmptyElement<Coord> {
+impl<Coord, DB: DrawingBackend> EmptyElement<Coord, DB> {
     pub fn at(coord: Coord) -> Self {
-        return Self { coord };
+        Self {
+            coord,
+            phantom: PhantomData,
+        }
     }
 }
 
-impl<Coord, Other> Add<Other> for EmptyElement<Coord>
+impl<Coord, Other, DB: DrawingBackend> Add<Other> for EmptyElement<Coord, DB>
 where
-    Other: Drawable,
+    Other: Drawable<DB>,
     for<'a> &'a Other: PointCollection<'a, BackendCoord>,
 {
-    type Output = BoxedElement<Coord, Other>;
+    type Output = BoxedElement<Coord, DB, Other>;
     fn add(self, other: Other) -> Self::Output {
-        return BoxedElement {
+        BoxedElement {
             offset: self.coord,
             inner: other,
-        };
+            phantom: PhantomData,
+        }
     }
 }
 
-impl<'a, Coord> PointCollection<'a, Coord> for &'a EmptyElement<Coord> {
+impl<'a, Coord, DB: DrawingBackend> PointCollection<'a, Coord> for &'a EmptyElement<Coord, DB> {
     type Borrow = &'a Coord;
     type IntoIter = Once<&'a Coord>;
     fn point_iter(self) -> Self::IntoIter {
-        return once(&self.coord);
+        once(&self.coord)
     }
 }
 
-pub struct BoxedElement<Coord, A: Drawable> {
+/// An composed element has only one component
+pub struct BoxedElement<Coord, DB: DrawingBackend, A: Drawable<DB>> {
     inner: A,
     offset: Coord,
+    phantom: PhantomData<DB>,
 }
 
-impl<'b, Coord, A: Drawable> PointCollection<'b, Coord> for &'b BoxedElement<Coord, A> {
+impl<'b, Coord, DB: DrawingBackend, A: Drawable<DB>> PointCollection<'b, Coord>
+    for &'b BoxedElement<Coord, DB, A>
+{
     type Borrow = &'b Coord;
     type IntoIter = Once<&'b Coord>;
     fn point_iter(self) -> Self::IntoIter {
-        return once(&self.offset);
+        once(&self.offset)
     }
 }
 
-impl<Coord, A> Drawable for BoxedElement<Coord, A>
+impl<Coord, DB: DrawingBackend, A> Drawable<DB> for BoxedElement<Coord, DB, A>
 where
     for<'a> &'a A: PointCollection<'a, BackendCoord>,
-    A: Drawable,
+    A: Drawable<DB>,
 {
-    fn draw<DB: DrawingBackend, I: Iterator<Item = BackendCoord>>(
+    fn draw<I: Iterator<Item = BackendCoord>>(
         &self,
         mut pos: I,
         backend: &mut DB,
@@ -63,62 +74,66 @@ where
             self.inner.draw(
                 self.inner.point_iter().into_iter().map(|p| {
                     let p = p.borrow();
-                    return (p.0 + x0, p.1 + y0);
+                    (p.0 + x0, p.1 + y0)
                 }),
                 backend,
             )?;
         }
-        return Ok(());
+        Ok(())
     }
 }
 
-impl<Coord, My, Yours> Add<Yours> for BoxedElement<Coord, My>
+impl<Coord, DB: DrawingBackend, My, Yours> Add<Yours> for BoxedElement<Coord, DB, My>
 where
-    My: Drawable,
+    My: Drawable<DB>,
     for<'a> &'a My: PointCollection<'a, BackendCoord>,
-    Yours: Drawable,
+    Yours: Drawable<DB>,
     for<'a> &'a Yours: PointCollection<'a, BackendCoord>,
 {
-    type Output = ComposedElement<Coord, My, Yours>;
+    type Output = ComposedElement<Coord, DB, My, Yours>;
     fn add(self, yours: Yours) -> Self::Output {
-        return ComposedElement {
+        ComposedElement {
             offset: self.offset,
             first: self.inner,
             second: yours,
-        };
+            phantom: PhantomData,
+        }
     }
 }
 
-pub struct ComposedElement<Coord, A, B>
+/// The composed element which has at least two components
+pub struct ComposedElement<Coord, DB: DrawingBackend, A, B>
 where
-    A: Drawable,
-    B: Drawable,
+    A: Drawable<DB>,
+    B: Drawable<DB>,
 {
     first: A,
     second: B,
     offset: Coord,
+    phantom: PhantomData<DB>,
 }
 
-impl<'b, Coord, A, B> PointCollection<'b, Coord> for &'b ComposedElement<Coord, A, B>
+impl<'b, Coord, DB: DrawingBackend, A, B> PointCollection<'b, Coord>
+    for &'b ComposedElement<Coord, DB, A, B>
 where
-    A: Drawable,
-    B: Drawable,
+    A: Drawable<DB>,
+    B: Drawable<DB>,
 {
     type Borrow = &'b Coord;
     type IntoIter = Once<&'b Coord>;
     fn point_iter(self) -> Self::IntoIter {
-        return once(&self.offset);
+        once(&self.offset)
     }
 }
 
-impl<Coord, A, B> Drawable for ComposedElement<Coord, A, B>
+impl<Coord, DB: DrawingBackend, A, B> Drawable<DB> for ComposedElement<Coord, DB, A, B>
 where
     for<'a> &'a A: PointCollection<'a, BackendCoord>,
     for<'b> &'b B: PointCollection<'b, BackendCoord>,
-    A: Drawable,
-    B: Drawable,
+    A: Drawable<DB>,
+    B: Drawable<DB>,
 {
-    fn draw<DB: DrawingBackend, I: Iterator<Item = BackendCoord>>(
+    fn draw<I: Iterator<Item = BackendCoord>>(
         &self,
         mut pos: I,
         backend: &mut DB,
@@ -127,41 +142,43 @@ where
             self.first.draw(
                 self.first.point_iter().into_iter().map(|p| {
                     let p = p.borrow();
-                    return (p.0 + x0, p.1 + y0);
+                    (p.0 + x0, p.1 + y0)
                 }),
                 backend,
             )?;
             self.second.draw(
                 self.second.point_iter().into_iter().map(|p| {
                     let p = p.borrow();
-                    return (p.0 + x0, p.1 + y0);
+                    (p.0 + x0, p.1 + y0)
                 }),
                 backend,
             )?;
         }
-        return Ok(());
+        Ok(())
     }
 }
 
-impl<Coord, A, B, C> Add<C> for ComposedElement<Coord, A, B>
+impl<Coord, DB: DrawingBackend, A, B, C> Add<C> for ComposedElement<Coord, DB, A, B>
 where
-    A: Drawable,
+    A: Drawable<DB>,
     for<'a> &'a A: PointCollection<'a, BackendCoord>,
-    B: Drawable,
+    B: Drawable<DB>,
     for<'a> &'a B: PointCollection<'a, BackendCoord>,
-    C: Drawable,
+    C: Drawable<DB>,
     for<'a> &'a C: PointCollection<'a, BackendCoord>,
 {
-    type Output = ComposedElement<Coord, A, ComposedElement<BackendCoord, B, C>>;
+    type Output = ComposedElement<Coord, DB, A, ComposedElement<BackendCoord, DB, B, C>>;
     fn add(self, rhs: C) -> Self::Output {
-        return ComposedElement {
+        ComposedElement {
             offset: self.offset,
             first: self.first,
             second: ComposedElement {
                 offset: (0, 0),
                 first: self.second,
                 second: rhs,
+                phantom: PhantomData,
             },
-        };
+            phantom: PhantomData,
+        }
     }
 }
