@@ -10,7 +10,8 @@ pub use color::{
     Black, Blue, Color, Cyan, Green, HSLColor, Magenta, Mixable, PaletteColor, RGBColor, Red,
     SimpleColor, Transparent, White, Yellow,
 };
-pub use font::{FontDesc, FontError, FontResult};
+
+pub use font::{FontDesc, FontError, FontResult, IntoFont};
 pub use palette::*;
 
 /// Denotes an style of a text
@@ -23,19 +24,25 @@ pub struct TextStyle<'a> {
 impl<'a> TextStyle<'a> {
     /// Determine the color of the style
     pub fn color<C: Color>(&self, color: &'a C) -> Self {
-        return Self {
+        Self {
             font: self.font,
             color,
-        };
+        }
+    }
+}
+
+impl<'a, 'b: 'a> Into<TextStyle<'a>> for &'b TextStyle<'a> {
+    fn into(self) -> TextStyle<'a> {
+        self.clone()
     }
 }
 
 impl<'a, T: Borrow<FontDesc<'a>>> From<&'a T> for TextStyle<'a> {
     fn from(font: &'a T) -> Self {
-        return Self {
+        Self {
             font: font.borrow(),
             color: &RGBColor(0, 0, 0),
-        };
+        }
     }
 }
 
@@ -49,18 +56,18 @@ pub struct ShapeStyle<'a> {
 impl<'a> ShapeStyle<'a> {
     /// Make a filled shape style
     pub fn filled(&self) -> Self {
-        return Self {
+        Self {
             color: self.color,
             filled: true,
-        };
+        }
     }
 }
 
 impl<'a, T: Color> From<&'a T> for ShapeStyle<'a> {
     fn from(f: &'a T) -> Self {
-        return ShapeStyle {
+        ShapeStyle {
             color: f,
             filled: false,
-        };
+        }
     }
 }
